@@ -49,13 +49,20 @@ Pt <- apply(Pt,2,cumsum)
 Ut <- apply(U,2,cumsum)
 
 nd <- nrow(object$U)
+Pt <-  .Call("XXMatFULL",Pt,p,PACKAGE="mets")$XXf
 Pt <-  .Call("CubeMat",Pt,ii,PACKAGE="mets")$XXX
 sup <- matrix(0,n.sim,nrow(ii))
 hatti <- matrix(0,nd,nrow(ii))
 obs <- apply(abs(Ut),2,max)
 
-if (is.null(robust)) 
+if (is.null(robust)) {
    if (!is.null(object$call.id)) robust <- TRUE else robust <- FALSE
+   if (inherits(object,c("cifreg"))) {
+	   robust <- FALSE  ## approximative test using MG framework
+###	   if (is.null(object$cox.prep)) stop("Must be called with cox.prep=TRUE\n")
+   }
+}
+
 
    ### cluster call or robust \hat M_i(t) based  
 if (robust) {# {{{
@@ -67,8 +74,8 @@ if (robust) {# {{{
    nn <- nrow(Z)
 
    tt <- system.time(simcox1<- .Call("PropTestCoxClust",UdN,Pt,rrw,xx$X,
-	     object$S0,object$E,
-             10,obs,nn,xx$id,xx$strata,xx$nstrata,object$strata.jumps,xx$jumps))
+     object$S0,object$E,
+     10,obs,nn,xx$id,xx$strata,xx$nstrata,object$strata.jumps,xx$jumps))
 
    prt <- n.sim*tt[3]/(10*60)
    if (prt>1 & silent==0) cat(paste("Predicted time minutes",signif(prt,2),"\n"))
@@ -99,7 +106,6 @@ class(out) <- "gof.phreg"
 return(out)
 }# }}}
 
-
 ##' GOF for Cox covariates in  PH regression
 ##'
 ##' Cumulative residuals after model matrix for Cox PH regression
@@ -131,7 +137,6 @@ return(out)
 ##' data(TRACE)
 ##' set.seed(1)
 ##' TRACEsam <- blocksample(TRACE,idvar="id",replace=FALSE,100)
-##' 
 ##' dcut(TRACEsam)  <- ~. 
 ##' mm <- model.matrix(~-1+factor(wmicat.4),data=TRACEsam)
 ##' m1 <- gofM.phreg(Surv(time,status==9)~vf+chf+wmi,data=TRACEsam,modelmatrix=mm)
@@ -158,11 +163,23 @@ gofM.phreg  <- function(formula,data,offset=NULL,weights=NULL,modelmatrix=NULL,
 if (is.null(modelmatrix)) stop(" must give matrix for cumulating residuals\n"); 
 
 cox1 <- phreg(formula,data,offset=NULL,weights=NULL,Z=modelmatrix,cumhaz=FALSE,...) 
+
+## put modelmatrix on data, and take y, strata from design
+datl <- as.data.frame(modelmatrix)
+namesmm <- paste("names",1:ncol(modelmatrix),sep="")
+names(datl) <- namesmm
+datl[,"y__"] <- cox1$design$y
+if (!is.null(cox1$design$strata)) {
+datl[,"strata__"] <- cox1$design$strata
+formM <- y__~strata(strata__)
+formM <- update(formM, paste(". ~ . +",paste(namesmm, collapse = " + ")))
+} else {
+formM <- as.formula(paste("y__~",paste(namesmm, collapse = " + ")))
+}
+
 offsets <- cox1$X %*% cox1$coef
 if (!is.null(offset)) offsets <- offsets*offset
-if (!is.null(cox1$strata.name)) 
-     coxM <- phreg(cox1$model.frame[,1]~modelmatrix+strata(cox1$strata),data,offset=offsets,weights=weights,no.opt=TRUE,cumhaz=FALSE,no.var=1,...)
-else coxM <- phreg(cox1$model.frame[,1]~modelmatrix,data,offset=offsets,weights=weights,no.opt=TRUE,cumhaz=FALSE,no.var=1,...)
+coxM <- phreg(formM,datl,offset=offsets,weights=weights,no.opt=TRUE,cumhaz=FALSE,no.var=1,...)
 nnames <- colnames(modelmatrix)
 
 Ut <- apply(coxM$U,2,cumsum)
@@ -365,8 +382,6 @@ cumContr <- function(data,breaks=4,probs=NULL,equi=TRUE,na.rm=TRUE,unique.breaks
 ##' gofG.phreg(m1)
 ##' gofG.phreg(m2)
 ##' 
-##' bplot(m1,log="y")
-##' bplot(m2,log="y")
 ##' @export
 gofG.phreg  <- function(x,sim=0,silent=1,lm=TRUE,...)
 {# {{{
@@ -378,8 +393,7 @@ nstrata <- x$nstrata
 jumptimes <- x$jumptimes
 cumhaz <- x$cumhaz
 
-ms <- match(x$strata.name,names(x$model.frame))
-lstrata <- levels(x$model.frame[,ms])
+lstrata <- as.numeric(x$design$strata)-1
 stratn <-  substring(x$strata.name,8,nchar(x$strata.name)-1)
 stratnames <- paste(stratn,lstrata,sep=":")
 
@@ -388,35 +402,37 @@ if (nstrata==1) stop("Stratified Cox to look at baselines");
 
 if ((x$no.opt) | is.null(x$coef)) fixbeta<- 1 else fixbeta <- 0
 
+
 for (i in 0:(nstrata-2))
 for (j in (i+1):(nstrata-1)) { 
       iij <- which(strata %in% c(i,j))
       ii <- which(strata %in% i)
       ij <- which(strata %in% j)
       dijjumps  <- jumptimes[iij] 
-      cumhazi <- Cpred(cumhaz[ii,],dijjumps,strict=FALSE)
-      cumhazj <- Cpred(cumhaz[ij,],dijjumps,strict=FALSE)
+      cumhazi <- predictCumhaz(rbind(0,cumhaz[ii,]),dijjumps)
+      cumhazj <- predictCumhaz(rbind(0,cumhaz[ij,]),dijjumps)
 
       plot(cumhazj[,2],cumhazi[,2],type="s",lwd=2,xlab=stratnames[j+1],ylab=stratnames[i+1])
       graphics::title(paste("Stratified baselines for",stratn))
       if ((fixbeta==0 | sim==0) & lm ) 
       graphics::legend("topleft",c("Nonparametric","lm"),lty=1,col=1:2)
-      ab <- lm(cumhazi[,2]~-1+cumhazj[,2])
-      if (sim==1 & fixbeta==0) {
-             Pt <- DLambeta.t <- apply(x$E/c(x$S0),2,cumsumstrata,strata,nstrata)
-             II <- -solve(x$hessian)
-             betaiid <- t(II %*% t(x$U))
-	     simband <-  .Call("simBandCumHazCox",1/x$S0,Pt,betaiid,50,rep(1,nrow(Pt)),PACKAGE="mets")
-	     simU <-simband$simUt
-	     for (k in 1:50)
-	     {
-	      di <- Cpred(cbind(jumptimes[ii],simU[ii,k]),dijjumps,strict=FALSE)[,2]
-	      dj <- Cpred(cbind(jumptimes[ij],simU[ij,k]),dijjumps,strict=FALSE)[,2]
-	      lines(cumhazj[,2]+dj,cumhazi[,2]+di,type="s",lwd=0.1,col=3)
-	     }
-      }
-      lines(cumhazj[,2],cumhazi[,2],type="s",lwd=2,col=1)
-      if (lm==TRUE) abline(c(0,coef(ab)),col=2,lwd=2)
+###      ab <- lm(cumhazi[,2]~-1+cumhazj[,2])
+      ## TODO: simBandCumHazCox
+      ## if (sim==1 & fixbeta==0) {
+      ##   Pt <- DLambeta.t <- apply(x$E/c(x$S0),2,cumsumstrata,strata,nstrata)
+      ##   II <- -solve(x$hessian)
+      ##   betaiid <- t(II %*% t(x$U))
+      ##   simband <-  .Call("simBandCumHazCox",1/x$S0,Pt,betaiid,50,rep(1,nrow(Pt)),PACKAGE="mets")
+      ##   simU <-simband$simUt
+      ##   for (k in 1:50)
+      ##   {
+	  ##     di <- cpred(cbind(jumptimes[ii],simU[ii,k]),dijjumps)[,2]
+	  ##     dj <- cpred(cbind(jumptimes[ij],simU[ij,k]),dijjumps)[,2]
+	  ##     lines(cumhazj[,2]+dj,cumhazi[,2]+di,type="s",lwd=0.1,col=3)
+      ##   }
+      ## }
+###      lines(cumhazj[,2],cumhazi[,2],type="s",lwd=2,col=1)
+###      if (lm==TRUE) abline(c(0,coef(ab)),col=2,lwd=2)
 }
 
 }# }}}
