@@ -538,7 +538,7 @@ Gcj <- NULL
 
 ## Fitting all models with augmentation terms 
 if (fit0$p>0) {
-coefMarg <- estimate(fit0,vcov=fit0$var,level=level)$coefmat
+coefMarg <- estimate(coef = coef(fit0), vcov = fit0$var, level = level)$coefmat
 var.names <- rownames(coefMarg)
 rownames(coefMarg) <- paste("Marginal",rownames(coefMarg),sep="-")
 coefs <- coefMarg
@@ -645,14 +645,12 @@ return(iid)
 
 ### sort iid after name.id and put as rownames
 if (!is.null(call.id)) {
-ea.iid <- namesortme(ea.iid,name.id)
-for (l in 1:length(iid)) iid[[l]] <- namesortme(iid[[l]],name.id)
-AugC.iid <- namesortme(AugC.iid,name.id)
-AugClt.iid <- namesortme(AugClt.iid,name.id)
+ea.iid <- nameme(ea.iid,name.id)
+for (l in 1:length(iid)) iid[[l]] <- nameme(iid[[l]],name.id)
+AugC.iid <- nameme(AugC.iid,name.id)
+AugClt.iid <- nameme(AugClt.iid,name.id)
 }
 
-###AugR0.iid <- namesortme(AugR0.iid,name.id)
-
 out <- list(marginal=fit0,AugR0=AugR0,AugR1=AugR1,AugR01=AugR01,AugCdyn=AugCdyn,
     AugClt=AugClt,
     coefs=coefs,iid=iid,AugC.iid=AugC.iid,AugClt.iid=AugClt.iid,Cox.iid=ea.iid,
